// src/index.ts
import { createRequire } from "module";
import { createSyncFn } from "synckit";
import { visit } from "unist-util-visit";
var ShikiRemarkPlugin = (options) => {
  const { themes = [], theme = "nord", generateMultiCode, langs } = options;
  const custHighlighter = options.highlighter;
  let syncRun;
  if (!custHighlighter) {
    const require2 = createRequire(import.meta.url);
    syncRun = createSyncFn(require2.resolve("./worker"));
    syncRun("getHighlighter", { langs, themes, theme });
  }
  function highlight(code, theme2, lang) {
    if (custHighlighter) {
      return custHighlighter.codeToHtml(code, { lang, theme: theme2, lineOptions: void 0 });
    } else {
      return syncRun("codeToHtml", {
        code,
        theme: theme2,
        lang
      });
    }
  }
  return function(tree) {
    visit(tree, "code", visitor);
    function visitor(node) {
      let highlightHTML;
      if (generateMultiCode) {
        const allHighlighted = themes.map((theme2) => {
          return highlight(node.value, theme2, node.lang || "text");
        });
        highlightHTML = `<div class="shiki-container">${allHighlighted.join("")}</div>`;
      } else {
        highlightHTML = highlight(node.value, theme, node.lang || "text");
      }
      node.type = "html";
      node.value = highlightHTML;
    }
  };
};
var src_default = ShikiRemarkPlugin;
export {
  src_default as default
};
